## Model curation

Data files used for performing curations to the model.

Curations between each model release are gathered in consolidated curation scripts that are named after the model version that they generate. E.g. v8_6_1.m includes updates that regenerates model version 8.6.1. These scripts can replicate the curation process, but earlier model releases are best downloaded here: https://github.com/SysBioChalmers/yeast-GEM/releases.

Organized in folders that indicate which model version will be generated when incorporating this data. E.g. 'v8_6_1' contains data files that is used to regenerate model version 8.6.1.

The data files here mainly exist of list with reactions, metabolites etc., and their annotations.

Data that conceivably could be used repeatedly (so not only to curate one specific model version), might be better kept in ../physiology or ../databases.
